@@ -50,6 +50,6 @@ pair_n <- function(x, y = NULL) {
 #' @examples
 #' x <- correlate(mtcars)
 #' as_matrix(x)
-as_matrix <- function(x, diagonal) {
+as_matrix <- function(x, diagonal = 1) {
   UseMethod("as_matrix")
 }
\ No newline at end of file
